**********
User Guide
**********

.. admonition:: Work in Progress
   :class: warning

   The user guide is incomplete. For the full list of packages and modules provided by
   ERLabPy, see :doc:`../reference`.

Introduction
============

Welcome to the ERLabPy user guide! This guide provides an overview of ERLabPy and its
core features.

If you are new to using ERLabPy, you may want to start with the `getting started guide
<../getting-started.rst>`_.

.. toctree::
   :caption: Table of Contents
   :maxdepth: 2

   imagetool
   io
   indexing
   plotting
   kconv
   curve-fitting
   filtering

Further reading
===============

- `Lectures on scientific computing with Python
  <https://github.com/jrjohansson/scientific-python-lectures>`_
- `The beginner's guide to numpy
  <https://numpy.org/doc/stable/user/absolute_beginners.html>`_
- `Xarray tutorial <https://tutorial.xarray.dev/>`_
